===================================
``psyclone.core.component_indices``
===================================

.. automodule:: psyclone.core.component_indices

   .. contents::
      :local:

.. currentmodule:: psyclone.core.component_indices


Classes
=======

- :py:class:`ComponentIndices`:
  This class stores index information for variable accesses. It stores


.. autoclass:: ComponentIndices
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ComponentIndices
      :parts: 1
